## Sigmund: your friendly, privacy-minded AI assistant!

&#128150; Your subscription<br>supports open source
{: .pretty-text }

- State-of-the-art chatbot
- Better at answering questions about [OpenSesame](https://osdoc.cogsci.nl/) and [DataMatrix](https://pydatamatrix.eu) than any other chatbot
- Search and summarize scientific literature (access to Google Scholar)
- Generate images (using Dall-E 3)
- Basic Python and R execution abilities
- Upload and download attachments
- Messages and attachments are encrypted so that no-one can listen in on your conversation
- Use your favorite language model! Select OpenAI GPT4o, Anthropic Claude 3.5, or Mistral Large
- Read more about [what Sigmund can do](/about) and [our terms of service](/terms)

Sigmund requires a subscription (€9 /month). You can subscribe after signing in. A variety of international payment methods are available. Subscribing is easy and secure.

If you need a custom subscription, such as an invoiced subscription for multiple individuals or a longer period, contact [professional@cogsci.nl](mailto:professional@cogsci.nl).

<a id="sign-in-button" class="link-button" onclick="signin()">
    <i class="fas fa-sign-in-alt"></i> Sign in with CogSci forum<br>
    <small>Use your account from forum.cogsci.nl</small>
</a>

<a id="sign-in-button" class="link-button" href="/google_login">
    <i class="fab fa-google"></i> Sign in with Google<br>
    <small>Use your Google account</small>
</a>
